@@ -21,6 +21,7 @@ require_once 'phplib/shortly.php';
 require_once 'phplib/result.php';
 require_once 'blacklist.php';
 require_once 'phplib/const.php';
+require_once 'phplib/signature.php';
 
 require_once 'phplib/smarty/Smarty.class.php';
 
@@ -87,7 +88,6 @@ if(!isset($_GET["type"])){
     $meta['samefiles'][] = $shortly[1];
     saveInfo($meta);
   }
-
   //--------------------------------------------
   //ページの表示
 
@@ -117,7 +117,9 @@ if(!isset($_GET["type"])){
  $DLTYPE = $_GET["type"];
  $DLNAME = $_GET["dlname"];
 
- if( !in_array($DLTYPE, array("zip","mht"))
+ $allowtypes =  array("zip","mht");
+
+ if( !in_array($DLTYPE, $allowtypes)
   || !(isset($DLTYPE)&&isset($DLNAME)&&readConfig("USEZIP"))){
    //typeかdlnameがない場合は404に飛ばす
    header("HTTP/1.1 404 Not Found");
@@ -147,7 +149,6 @@ if(!isset($_GET["type"])){
    $MhtFileMaker->AutoAddFiles();
    $MhtFileMaker->MakeFileWithWriter('pzip_stdout_writer','dummy');
   }
-
  }else{
   //ダウンロードファイルを生成してからダウンロードさせる
   $dlurl  = ""; //ダウンロードurl
@@ -203,7 +204,7 @@ if(!isset($_GET["type"])){
   header('Content-Type: application/force-download');
   header('Content-Length: ' . $dlsize);
   header('Content-disposition: attachment; filename="'.$DLNAME.'"');
-  
+
   $last_modified = gmdate( "D, d M Y H:i:s T", $meta['date'] );
   $etag = md5( $last_modified . __FILE__ . $meta["url"] );
   header('Pragma: cache');
