@@ -104,7 +104,7 @@ function cnvNone($src,$convparam) {
 //サムネの抜き出しとURL書き換えを行う
 function cnvThumb($src,$convparam,$url) {
   // 避難所用
-  $reg = "/(.*)src=[\"\'](\/.*\/thumb\/[^\"^\']*)[\"\'](.*)/i";
+  $reg = "/(.*)src=[\"\'](\/[^\/]*\/thumb\/[^\"^\']*)[\"\'](.*)/i";
   $matches = array();
   if(preg_match($reg, $src, $matches) == 1){
     $fname = str_replace("/","_",$matches[2]);
@@ -112,17 +112,15 @@ function cnvThumb($src,$convparam,$url) {
     if(preg_match("/([^\/]+)$/i", $matches[2], $mc) == 1) {
       $fname = $mc[1];
     }
-    $host = "www.2chan.net";
-    if(preg_match("/https?:\/\/([^\/]+).*/", $url, $hm) == 1){
-      $host = $hm[1];
-    }
+    preg_match('@^(?:http://)?([^/]+)@i', $url, $hm);
+    $host = $hm[1];
     return array($matches[1] . "src=\"" . $convparam . $fname . "\"" . $matches[3]
                  ,$src,
-                 $host."/".$matches[2],
+                 $host.$matches[2],
                  $convparam . $fname );
   }
   // 通常のふたば用
-  $reg = "/(.*)src=[\"\']http:\/\/(.*\.2chan.net\/.*\/thumb\/[^\"^\']*)[\"\'](.*)/i";
+  $reg = "/(.*)src=[\"\'][^\/]*\/\/(.*\.2chan.net\/.*\/thumb\/[^\"^\']*)[\"\'](.*)/i";
   $matches = array();
   if(preg_match($reg, $src, $matches) == 1){
     $fname = str_replace("/","_",$matches[2]);
@@ -141,7 +139,7 @@ function cnvThumb($src,$convparam,$url) {
 //リンク先画像のURL書き換えを行う
 function cnvLink($src,$convparam,$url) {
   // 避難所用
-  $reg = "/(.*)href=[\"\'](\/.*\/src\/[^\"^\']*)[\"\'](.*)/i";
+  $reg = "/(.*)href=[\"\'](\/[^\/]*\/src\/[^\"^\']*)[\"\'](.*)/i";
   $matches = array();
   if(preg_match($reg, $src, $matches) == 1){
     $fname = str_replace("/","_",$matches[2]);
@@ -153,17 +151,15 @@ function cnvLink($src,$convparam,$url) {
     if(useLightBox() && isImageFileExt($fname)) {
       $lbparam = ' rel="lightbox"';
     }
-    $host = "www.2chan.net";
-    if(preg_match("/https?:\/\/([^\/]+).*/", $url, $hm) == 1){
-      $host = $hm[1];
-    }
+    preg_match('@^(?:http://)?([^/]+)@i', $url, $hm);
+    $host = $hm[1];
     return array($matches[1] . "href=\"" . $convparam . $fname . "\"" . $lbparam . $matches[3]
                  ,$src,
-                 $host."/".$matches[2],
+                 $host.$matches[2],
                  $convparam . $fname );
   }
   // 通常のふたば用
-  $reg = "/(.*)href=[\"\']http:\/\/(.*\.2chan.net\/.*\/src\/[^\"^\']*)[\"\'](.*)/i";
+  $reg = "/(.*)href=[\"\'][^\/]*\/\/(.*\.2chan.net\/.*\/src\/[^\"^\']*)[\"\'](.*)/i";
   $matches = array();
   if(preg_match($reg, $src, $matches) == 1){
     $fname = str_replace("/","_",$matches[2]);
@@ -557,7 +553,7 @@ function cust_pget($url,$storeDir,
   if(readConfig("CONTDIRREADONLY")){
     return false;
   }
-  
+
   //その他の格納フォルダ(other/)の作成
   if(!file_exists($storeDir . _PGET_OTHER_DIR_)) {
     mkdir($storeDir . _PGET_OTHER_DIR_);
@@ -644,19 +640,19 @@ function cust_pget($url,$storeDir,
     $convHtml = preg_replace(
       "/<div class=[\"\']thre[\"\']/",
       '<span class="thre"',$convHtml);
-    
+
     $convHtml = pgetRmTag($convHtml, 'div', true);
     $result   = pgetParseHtml($convHtml, '/div', 'cnvNone', "", $url);
     $convHtml = $result[0];
-    
+
     $convHtml = pgetRmTag($convHtml, 'iframe', true);
   }
-  
+
   //mailtoの展開
   $convHtml = preg_replace(
     "/<a href=[\"\']mailto:([^\"^\']*)[\"\']>([^<]*)<\/a>/",
     "$2 <font color=green>$1</font>",$convHtml);
-  
+
   //画像一覧を通知
   $imageUrls = array();
   foreach($convResults as $ret){
