@@ -40,7 +40,7 @@ require_once 'dba/DBA_chunkfile.php';
 function _readDBAConfig()
 {
   $confpath = readConfig("METADIR") . DBACONFNAME;
-  
+
   if(is_file($confpath)){
     return unserialize(file_get_contents($confpath));
   }else{
@@ -62,7 +62,7 @@ function _readDBAConfig()
       $conf["kvstype"] = "sqlite3";
     }
     //*/
-    
+
     file_put_contents( $confpath, serialize($conf) );
     return $conf;
   }
@@ -201,7 +201,7 @@ function readAllInfo()
 function readAllInfoCached()
 {
   $allinfo = array();
-  
+
   if(USEFULLCACHE){
     $lockpath = readConfig("LOCKDIR") . FULLCACHENAME . ".lock";
     if($lock = fopen($lockpath, 'w')){
@@ -312,7 +312,7 @@ function meta_verifyInfo($src)
   if($newinfo["lost"] === true){
     $newinfo["lost"] = 3;
   }
-  
+
   //filehashの計算
   if(get_value($newinfo, "htmlhash", "") == ""){
     $gzfilename = readConfig("CONTDIR") . $basenames["CONT"] . (_PGET_OTHER_DIR_._PGET_INDEX_PAGE_SRCGZ_);
@@ -375,6 +375,39 @@ function remove_directory($dir) {
   }
 }
 
+/*
+ * 公開可能なメンバのみ抽出
+ */
+function publishInfo($meta) {
+  $keys = array(
+    "date",
+    "title",
+    "store_url",
+    "url",
+    "thumb",
+    "res",
+    "lost",
+    "ng",
+    "du",
+    "res_count",
+    "life_time",
+    "first_date" ,
+    "user_update" ,
+    "tags",
+    "src1res_day",
+    "src1res_time",
+    "other_files",
+    "htmlhash",
+    );
+  $newinfo = array();
+  foreach($meta as $k => $v) {
+    if(in_array($k,$keys)){
+      $newinfo[$k] = $v;
+    }
+  }
+  return $newinfo;
+}
+
 /**
  *urlで指定したinfoと関連する情報を削除する
  */
@@ -412,7 +445,7 @@ function removePage($url)
            && file_exists($target))
         {
           remove_directory($target);
-        }        
+        }
       }
 
       $target = readConfig("ZIPDIR") . $basenames["ZIP"];
